::cisco::eem::event_register_syslog occurs 1 pattern .*LINEPROTO-.*-UPDOWN:.*up maxrun 90
#----------------------------------
# EEM policy that will enable interface performance statistics collections
# automatically upon recept of line protocol up event
#
# Copyright (c) February 2009, jepalmer@cisco.com
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. Neither the name of Cisco, the name of the copyright holder nor the
#    names of their respective contributors may be used to endorse or
#    promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
#
#----------------------------------
### The following EEM environment variables are used:
###
### interface_pattern (mandatory)	- Pattern of Interfaces to configure
###
### Example: interface_pattern		  Ethernet0/[2-3]
###
### BulkStatsName (mandatory)		- Used to determin collector to use
###
### Example: BulkStatsName		  15Min_InterfaceData_1.1.1.1
###
# check if all the env variables we need exist
# If any of them doesn't exist, print out an error msg and quit
if {![info exists interface_pattern]} {
	set result \
		"Policy cannot be run: variable interface_pattern has not been set"
	error $result $errorInfo
}
if {![info exists BulkStatsName]} {
	set result \
		"Policy cannot be run: variable BulkStatsName has not been set"
	error $result $errorInfo
}
namespace import ::cisco::eem::*
namespace import ::cisco::lib::*

proc AddSchema {ifindexnum interfacename} {
	global BulkStatsName
	if [catch {cli_open} result] {
	error $result $errorInfo
	} else {
	array set cli1 $result
	}
	if [catch {cli_exec $cli1(fd) "enable"} result] {
		error $result $errorInfo
	} else {
		if [catch {cli_exec $cli1(fd) "configure terminal"} result] {
		error $result $errorInfo
		} else {
			if [catch {cli_exec $cli1(fd) "snmp mib bulkstat schema if15MinSchema_$ifindexnum"} result] {
				error $result $errorInfo
			} else {
				if [catch {cli_exec $cli1(fd) "object-list if15MinOIDList"} result] {
					error $result $errorInfo
				} else {
					if [catch {cli_exec $cli1(fd) "poll-interval 5"} result] {
						error $result $errorInfo
					} else {
						if [catch {cli_exec $cli1(fd) "instance exact interface $interfacename"} result] {
							error $result $errorInfo
						} else {
							if [catch {cli_exec $cli1(fd) "snmp mib bulkstat transfer $BulkStatsName"} result] {
								error $result $errorInfo
							} else {
								if [catch {cli_exec $cli1(fd) "schema if15MinSchema_$ifindexnum"} result] {
									error $result $errorInfo
								} else {
									if [catch {cli_exec $cli1(fd) "enable"} result] {
										error $result $errorInfo
									} else {
										if [catch {cli_exec $cli1(fd) "end"} result] {
											error $result $errorInfo
										} else {
											set msg [format "Interface %s (Index %d) now being monitored" $interfacename $ifindexnum ]
											action_syslog priority info msg $msg
											if [catch {cli_exec $cli1(fd) "write memory"} result] {
												error $result $errorInfo
											}
										}
									}
								}
							}
						}
					}
				}
			}
		}
	}
	if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
		error $result $errorInfo
	}
	return {Done}
}
proc Getifindex {interfacename} {
	if [catch {cli_open} result] {
	error $result $errorInfo
	} else {
	array set cli1 $result
	}
	if [catch {cli_exec $cli1(fd) "enable"} result] {
		error $result $errorInfo
	}
	if [catch {cli_exec $cli1(fd) "term len 0"} result] {
		error $result $errorInfo
	}
	set idx -1
	if [catch {cli_exec $cli1(fd) "show snmp mib ifmib ifindex $interfacename" } result] {
		error $result $errorInfo
	} else {
	set pat {.*Ifindex = ([0-9]+).*}
	regexp $pat $result match idx
	if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
		error $result $errorInfo
	}
	return $idx
	}

}
proc CheckForSchema {num} {
	if [catch {cli_open} result] {
		error $result $errorInfo
	} else {
	array set cli1 $result
	}
	if [catch {cli_exec $cli1(fd) "enable"} result] {
		error $result $errorInfo
	}
	if [catch {cli_exec $cli1(fd) "term len 0"} result] {
		error $result $errorInfo
	}
	if [catch {cli_exec $cli1(fd) "show running-config | include snmp mib bulkstat schema if15MinSchema_$num\$" } result] {
		error $result $errorInfo
	} else {
		set pat {.*if15MinSchema_([0-9]+).*}
		foreach line [split $result \n ] {
			regexp $pat $line match _val
			if {[info exists _val]} {			;# Found a Schema #
				if { $_val == $num } {
					if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
						error $result $errorInfo
					}
					return {True}			;# It was found you can stop now
				}
				unset _val
			}
		}
	}
	if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
		error $result $errorInfo
	}
	return {False}
}
# 1. query the information of latest triggered eem event
array set arr_einfo [event_reqinfo]
if {$_cerrno != 0} {
    set result [format "component=%s; subsys err=%s; posix err=%s;\n%s" \
      $_cerr_sub_num $_cerr_sub_err $_cerr_posix_err $_cerr_str]
    error $result 
}
set ipat {.*Interface (.*),.*}
regexp $ipat $arr_einfo(msg) match intf
# 2. check if  interface in event matches the interface_pattern
if {[info exists intf]} {
	regexp $interface_pattern $intf intfmatch
	if {[info exists intfmatch]} {						;# Interface matches pattern to configure
		set index [Getifindex $intf]						;# Get ifIndex of the interface
		set schemafound [CheckForSchema $index]				;# Look to see if already configured
		if { $schemafound == {False} } {
			set stat [AddSchema $index $intf]		;		# Configure the interface for collection
			}
		}
	}
